@@ -6,20 +6,18 @@
 #define _SELINUX_GET_DEFAULT_TYPE_H_
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /* Return path to default type file. */
-const char *selinux_default_type_path(void);
+	const char *selinux_default_type_path(void);
 
 /* Get the default type (domain) for 'role' and set 'type' to refer to it.
    Caller must free via free().
    Return 0 on success or -1 otherwise. */
-int get_default_type (const char* role, char** type);
+	int get_default_type(const char *role, char **type);
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif  /* ifndef _GET_DEFAULT_TYPE_H_ */
+#endif				/* ifndef _GET_DEFAULT_TYPE_H_ */
